@@ -5,8 +5,13 @@
 from w3bsite.classes.config import *
 
 # the database class.
-class Database(object):
+class Database(syst3m.objects.Traceback):
 	def __init__(self, firestore=None, path=None):
+		
+		# traceback.
+		syst3m.objects.Traceback.__init__(self, "w3bsite.Website.database")
+
+		# attributes.
 		self.firestore = firestore
 		self.path = gfp.clean(path)
 		self.file_path = self.fp = FilePath(self.path)
@@ -18,21 +23,26 @@ class Database(object):
 		self.cache = None
 		if self.firestore != None:
 			self.cache = syst3m.cache.Cache(path=self.path)
+
+		#
 	def load(self, path=None, format="str"):
+		if path == None: return r3sponse.error(self.__traceback__(function="load")+" Define parameter: [path].")
 		if self.firestore != None:
-			return self.firestore.load(reference)
+			return self.firestore.load(path)
 		elif self.cache != None:
-			return self.cache.load(group=reference, format=format)
+			return self.cache.load(group=path, format=format)
 	def save(self, path=None, data=None, format="str"):
+		if path == None: return r3sponse.error(self.__traceback__(function="save")+" Define parameter: [path].")
 		if self.firestore != None:
-			return self.firestore.load(reference, data)
+			return self.firestore.load(path, data)
 		elif self.cache != None:
-			return self.cache.save(group=reference, data=data, format=format)
+			return self.cache.save(group=path, data=data, format=format)
 	def delete(self, path=None, data=None, format="str"):
+		if path == None: return r3sponse.error(self.__traceback__(function="delete")+" Define parameter: [path].")
 		if self.firestore != None:
-			return self.firestore.delete(reference)
+			return self.firestore.delete(path)
 		elif self.cache != None:
-			return self.cache.delete(group=reference)
+			return self.cache.delete(group=path)
 	# str representation.
 	def __str__(self):
 		return str(self.fp.path)
